@@ -1,29 +1,29 @@
-mvrnormSeries <- function(NV=1, D, T, sigma.e, 
+mvrnormSeries <- function(NV=1, D, TI, sigma.e, 
    rho.dyn, sigma.v.dyn, sigma.u.dyn, rho.u.dyn,
    rho.RY, sigma.v.RY, sigma.u.RY, rho.u.RY,
    tol=1e-6, conditional.mean=FALSE) {
-  if (missing(T)) stop("'T' must be specified")
-  if (T < 3) stop("'T' must be >2")
-  if (class(sigma.e) == "list") {
+  if (missing(TI)) stop("'TI' must be specified")
+  if (TI < 3) stop("'TI' must be >2")
+  if (inherits(sigma.e, "list")) {
     if (missing(D)) { 
       D <- length(sigma.e) 
     } else {
       if (D != length(sigma.e)) 
         stop("the length of 'sigma.e' must agree with D")
     }
-    lapply(sigma.e, FUN = function(x) { if (!all(dim(x) == c(NV*T, NV*T) )) 
+    lapply(sigma.e, FUN = function(x) { if (!all(dim(x) == c(NV*TI, NV*TI) )) 
       stop(paste("each element of 'sigma.e' must be a square matrix",
-        "with 'NV*T' rows"))
+        "with 'NV*TI' rows"))
      } )
   } else {
     if (missing(D)) stop("'D' must be specified")
-    if (class(sigma.e) != "matrix") 
+    if (!inherits(sigma.e, "matrix"))
       stop("'sigma.e' must be a matrix or a list of matrices")
-    if (!all(dim(sigma.e) == c(NV*T, NV*T) ))
-      stop("'sigma.e' must be a square matrix with 'NV*T' rows")
+    if (!all(dim(sigma.e) == c(NV*TI, NV*TI) ))
+      stop("'sigma.e' must be a square matrix with 'NV*TI' rows")
   }
-  sigma <- matrix(0, NV*T, NV*T)
-  mu <- rep(0, NV*T)
+  sigma <- matrix(0, NV*TI, NV*TI)
+  mu <- rep(0, NV*TI)
   if (!(missing(rho.dyn) | missing(sigma.v.dyn) | missing(sigma.u.dyn))) {
     if (missing(rho.dyn) | missing(sigma.v.dyn) | missing(sigma.u.dyn))
       stop("some parameters missing for dynamic model")
@@ -31,8 +31,8 @@ mvrnormSeries <- function(NV=1, D, T, sigma.e,
       if(length(sigma.v.dyn) != 1 |
          length(sigma.u.dyn) != 1)
         stop("wrong length for 'sigma.v.dyn' or 'sigma.u.dyn'")
-      sigma <- sigma.v.dyn*Gamma_v_f(rho.dyn, T)[[1]] +
-               sigma.u.dyn*Gamma_u_f(rho.dyn, T)[[1]]
+      sigma <- sigma.v.dyn*Gamma_v_f(rho.dyn, TI)[[1]] +
+               sigma.u.dyn*Gamma_u_f(rho.dyn, TI)[[1]]
     } else {
       if(missing(rho.u.dyn)) stop("'rho.u.dyn' must be specified")
       len.rho <- (NV*(NV-1))/2
@@ -52,20 +52,20 @@ mvrnormSeries <- function(NV=1, D, T, sigma.e,
       sqrt_u <- sqrt(sigma.u.dyn)
       sqrt_v <- sqrt(sigma.v.dyn)
       sigma  <- 
-        ((sqrt_u%*%t(sqrt_u)) * u_corr) %x% Gamma_u_f(rho.dyn, T)[[1]] +
-        ((sqrt_v%*%t(sqrt_v)) * u_corr) %x% Gamma_v_f(rho.dyn, T)[[1]]
+        ((sqrt_u%*%t(sqrt_u)) * u_corr) %x% Gamma_u_f(rho.dyn, TI)[[1]] +
+        ((sqrt_v%*%t(sqrt_v)) * u_corr) %x% Gamma_v_f(rho.dyn, TI)[[1]]
     }
   }
   if (!(missing(rho.RY) | missing(sigma.v.RY) | missing(sigma.u.RY))) {
     if (missing(rho.RY) | missing(sigma.v.RY) | missing(sigma.u.RY))
       stop("some parameters missing for Rao-Yu model")
-    Gamma_v <- matrix(1,nrow=T,ncol=T)
-    Gamma_b <- matrix(rep(1:T,times=T),nrow=T, ncol=T)
+    Gamma_v <- matrix(1,nrow=TI,ncol=TI)
+    Gamma_b <- matrix(rep(1:TI,times=TI),nrow=TI, ncol=TI)
     Gamma_s <- abs(Gamma_b-t(Gamma_b))
     if(rho.RY > 0) {
      Gamma_u <- rho.RY^(Gamma_s)/(1-rho.RY^2)
     } else {
-     Gamma_u <- diag(T)
+     Gamma_u <- diag(TI)
     }
     if (NV ==1) {
       if(length(sigma.v.RY) != 1 |
@@ -97,57 +97,57 @@ mvrnormSeries <- function(NV=1, D, T, sigma.e,
     }
   }
   if (NV == 1) {
-    y <- rep(0, D*T)
+    y <- rep(0, D*TI)
     if(conditional.mean) {
-      y.mean <- rep(0, D*T)
+      y.mean <- rep(0, D*TI)
       for (i in 1:D) {
-        y.mean[((i-1)*T + 1):(i*T)] <-
+        y.mean[((i-1)*TI + 1):(i*TI)] <-
             mvrnorm(mu=mu, Sigma=sigma, tol=tol)
       }
     }      
-    if(class(sigma.e) == "list") {
+    if(inherits(sigma.e, "list")) {
       if(conditional.mean) {
         for (i in 1:D) {
-          y[((i-1)*T + 1):(i*T)] <- y.mean[((i-1)*T + 1):(i*T)] +
+          y[((i-1)*TI + 1):(i*TI)] <- y.mean[((i-1)*TI + 1):(i*TI)] +
             mvrnorm(mu=mu, Sigma=sigma.e[[i]], tol=tol)
         }
       } else {
         for (i in 1:D) {
-          y[((i-1)*T + 1):(i*T)] <-
+          y[((i-1)*TI + 1):(i*TI)] <-
             mvrnorm(mu=mu, Sigma=sigma+sigma.e[[i]], tol=tol)
         }
       }
     } else {
       if(conditional.mean) {
         for (i in 1:D) {
-          y[((i-1)*T + 1):(i*T)] <- y.mean[((i-1)*T + 1):(i*T)] +
+          y[((i-1)*TI + 1):(i*TI)] <- y.mean[((i-1)*TI + 1):(i*TI)] +
             mvrnorm(mu=mu, Sigma=sigma.e, tol=tol)
         }
       } else {
         for (i in 1:D) {
-          y[((i-1)*T + 1):(i*T)] <-
+          y[((i-1)*TI + 1):(i*TI)] <-
             mvrnorm(mu=mu, Sigma=sigma+sigma.e, tol=tol)
         }
       }
     }
   } else {
-    y <- matrix(0, nrow=D*T, ncol=NV)
+    y <- matrix(0, nrow=D*TI, ncol=NV)
     if(conditional.mean) {
-      y.mean <- matrix(0, nrow=D*T, ncol=NV)
+      y.mean <- matrix(0, nrow=D*TI, ncol=NV)
       for (i in 1:D) {
         y.mean.temp <- mvrnorm(mu=mu, Sigma=sigma, tol=tol)
         for (nv in 1:NV) {
-           y.mean[((i-1)*T+1):(i*T), nv] <- y.mean.temp[((nv-1)*T+1):(nv*T)]
+           y.mean[((i-1)*TI+1):(i*TI), nv] <- y.mean.temp[((nv-1)*TI+1):(nv*TI)]
         } 
       }
     }
-    if(class(sigma.e) == "list") {
+    if(inherits(sigma.e, "list")) {
       if(conditional.mean) {
         for (i in 1:D) {
           y.temp <- mvrnorm(mu=mu, Sigma=sigma.e[[i]], tol=tol)
           for (nv in 1:NV) {
-             y[((i-1)*T+1):(i*T), nv] <- y.mean[((i-1)*T+1):(i*T), nv] + 
-                  y.temp[((nv-1)*T+1):(nv*T)]
+             y[((i-1)*TI+1):(i*TI), nv] <- y.mean[((i-1)*TI+1):(i*TI), nv] + 
+                  y.temp[((nv-1)*TI+1):(nv*TI)]
           }
         }
       } else {   
@@ -155,7 +155,7 @@ mvrnormSeries <- function(NV=1, D, T, sigma.e,
           y.temp <- 
              mvrnorm(mu=mu, Sigma=sigma+sigma.e[[i]], tol=tol)
           for (nv in 1:NV) {
-             y[((i-1)*T+1):(i*T), nv] <- y.temp[((nv-1)*T+1):(nv*T)]
+             y[((i-1)*TI+1):(i*TI), nv] <- y.temp[((nv-1)*TI+1):(nv*TI)]
           }
         }
       }
@@ -164,8 +164,8 @@ mvrnormSeries <- function(NV=1, D, T, sigma.e,
         for (i in 1:D) {
           y.temp <- mvrnorm(mu=mu, Sigma=sigma.e, tol=tol)
           for (nv in 1:NV) {
-             y[((i-1)*T+1):(i*T), nv] <- y.mean[((i-1)*T+1):(i*T), nv] + 
-                  y.temp[((nv-1)*T+1):(nv*T)]
+             y[((i-1)*TI+1):(i*TI), nv] <- y.mean[((i-1)*TI+1):(i*TI), nv] + 
+                  y.temp[((nv-1)*TI+1):(nv*TI)]
           }
         }
       } else {
@@ -173,7 +173,7 @@ mvrnormSeries <- function(NV=1, D, T, sigma.e,
           y.temp <- 
               mvrnorm(mu=mu, Sigma=sigma+sigma.e, tol=tol)
           for (nv in 1:NV) {
-             y[((i-1)*T+1):(i*T), nv] <- y.temp[((nv-1)*T+1):(nv*T)]
+             y[((i-1)*TI+1):(i*TI), nv] <- y.temp[((nv-1)*TI+1):(nv*TI)]
           }
         }
       }
